CLARITE Documentation
=====================

CLeaning to Anlaysis: Reproducibility-based Interface for Traits and Exposures

.. toctree::
   :maxdepth: 2

   motivation
   installation
   usage
   complex_surveys

API Reference
-------------

If you are looking for information on a specific function, class or
method, this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   api

CLI Reference
-------------

Documentation for using the CLI

.. toctree::
   :maxdepth: 2

   cli

Additional Notes
----------------

Release History, etc

.. toctree::
   :maxdepth: 2

   release-history
